mafw.enumerators
================

.. automodule:: mafw.enumerators

   
   .. rubric:: Classes

   .. autosummary::
   
      LoopType
      LoopingStatus
      ProcessorExitStatus
      ProcessorStatus
   